@@ -23,6 +23,7 @@
 #ifndef FILE_UTILS_H
 #define FILE_UTILS_H
 
+#include <sys/types.h>
 #include <time.h>
 #include <libgnomevfs/gnome-vfs-file-size.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
@@ -30,6 +31,11 @@
 
 #define FILENAME_MAX_LENGTH 30 /* FIXME: find out the best value */
 
+#define get_home_relative_dir(x)        \
+        g_strconcat (g_get_home_dir (), \
+                     "/",               \
+                     (x),               \
+                     NULL)
 
 gboolean            path_is_file                 (const gchar *s);
 
@@ -79,7 +85,8 @@ gchar *             shell_escape                 (const gchar *filename);
 gchar *             application_get_command      (const GnomeVFSMimeApplication *app);
 
 gboolean            match_patterns               (char       **patterns, 
-						  const char  *string);
+						  const char  *string,
+						  int          flags);
 
 char **             search_util_get_patterns     (const char  *pattern_string);
 
@@ -90,10 +97,16 @@ gboolean            rmdir_recursive              (const gchar *directory);
 char *              _g_strdup_with_max_size      (const char *s,
 						  int         max_size);
 
-#define get_home_relative_dir(x)        \
-        g_strconcat (g_get_home_dir (), \
-                     "/",               \
-                     (x),               \
-                     NULL)
+const char *        eat_spaces                   (const char *line);
+
+char **             split_line                   (const char *line, 
+						  int   n_fields);
+
+const char *        get_last_field               (const char *line,
+						  int         last_field);
+
+
+char *              get_temp_work_dir_name       ();
+
 
 #endif /* FILE_UTILS_H */
